@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.2.3';
+$VERSION = '0.2.4';
 ##------------------------------------------------------------------------------
 package sqlQuery;
 
@@ -86,11 +86,7 @@ sub foundRows
 
 sub getLastInsertId
 	{
-		my $res = __PACKAGE__->new(q(SELECT LAST_INSERT_ID()))->execute;
-		my $id = $res->fetchColumn(0);
-		$res->freeResource();
-
-		return $id
+		return $sqlQuery::DBI->last_insert_id(undef, undef, undef, undef);
 	}
 
 sub new
@@ -586,6 +582,7 @@ use strict;
 use warnings;
 use base 'sqlParameter';
 use Carp qw(croak);
+use Scalar::Util 'blessed';
 
 sub new {
 	my $self = shift->SUPER::new(@_);
@@ -593,6 +590,12 @@ sub new {
 	unless (@{$self->{-value}}) {
 		local $Carp::CarpLevel = $Carp::CarpLevel + 2; ## no critic
 		croak 'Empty lists can break SQL syntax.';
+	} else {
+		$self->{-value} = [map {
+			blessed($_) && $_->isa('sqlParameter')
+				? $_
+				: sqlQuery::convertArgument($_)
+		} @{$self->{-value}}];
 	}
 
 	return $self
@@ -690,10 +693,10 @@ sub gatherBoundArgs
 		my (@args);
 
 		push @args, @{$self->{boundArgs}}
-			if $self->{boundArgs};
+			if defined $self->{boundArgs};
 		push @args, $self->gatherConditionArgs();
 
-		if ($self->{prev}) {
+		if (defined $self->{prev}) {
 			push @args, $self->{prev}->gatherBoundArgs();
 		}
 
@@ -708,7 +711,7 @@ sub assemble
 		my $assembled = $self->_assemble();
 
 		$assembled = $self->{prev}->assemble() . $assembled
-			if $self->{prev};
+			if defined $self->{prev};
 
 		return $assembled
 	}
@@ -952,7 +955,7 @@ sub gatherConditionArgs
 		my @args;
 
 		push @args, $self->{havingCond}->getBoundArgs()
-			if $self->{havingCond};
+			if defined $self->{havingCond};
 		return @args
 	}
 
@@ -1033,7 +1036,7 @@ sub gatherConditionArgs
 		my @args;
 
 		push @args, $self->{whereCond}->getBoundArgs()
-			if $self->{whereCond};
+			if defined $self->{whereCond};
 		return @args
 	}
 
@@ -1108,8 +1111,8 @@ sub _assemble
 				unless (ref $condition) {
 					$j .= "USING(`$condition`)";
 				} elsif ($condition->isa('sqlCondition')) {
-					$_ = $condition->assemble();
-					$j .= "ON($_)";
+					my $cond = $condition->assemble();
+					$j .= "ON($cond)";
 				} else {
 					confess sprintf 'Cannot use argument "%s" as join condition', $condition;
 				}
@@ -1175,7 +1178,7 @@ sub assemble
 		given($self->{type}) {
 
 			when([TYPE_CONNECT_AND, TYPE_CONNECT_OR]) {
-				return unless $self->{_parts};
+				return unless defined $self->{_parts};
 				my ($glue) = (TYPE_CONNECT_AND == $self->{type} ? ' AND ' : ' OR ');
 				return '('.join($glue, map {$_->assemble()} @{$self->{_parts}}).')';
 			}
@@ -1187,8 +1190,8 @@ sub assemble
 			}
 
 			when([TYPE_UNARY_NOT]) {
-				$_ = $self->{_argument}->assemble();
-				return "NOT($_)";
+				my $stmt = $self->{_argument}->assemble();
+				return "NOT($stmt)";
 			}
 		}
 
@@ -1239,7 +1242,7 @@ sub overloadOr
 sub add
 	{
 		my $self = shift;
-		$self->{_parts} = [] unless $self->{_parts};
+		$self->{_parts} = [] unless defined $self->{_parts};
 
 		push @{$self->{_parts}}, @_;
 		$_->setParent($self) foreach @_;
@@ -1425,7 +1428,7 @@ sub insert
 	{
 		my $self = shift;
 
-		$self->{_parts} = [] unless $self->{_parts};
+		$self->{_parts} = [] unless defined $self->{_parts};
 		return $self->add(@_);
 	}
 
@@ -1436,9 +1439,9 @@ sub _bind
 			{parameter => {isa => 'sqlParameter'}};
 
 		push @{$self->{_queryArguments}}, $parameter
-			unless $self->{parent};
+			unless defined $self->{parent};
 		$self->{parent}->up()->_bind($parameter)
-				if $self->{parent};
+				if defined $self->{parent};
 		return $self
 	}
 
@@ -1469,7 +1472,7 @@ __END__
 
 =pod
 
-=for stopwords SQL PHP Schieche OO schieche namespace Booleans boolean unary falsy ad-hoc sqlQuery DBI prolog timestamp ARRAYREFs MySQL's HASHREFs
+=for stopwords SQL PHP Schieche OO schieche namespace Booleans boolean un unary falsy ad-hoc sqlQuery DBI prolog timestamp ARRAYREFs MySQL's HASHREFs
 
 =head1 NAME
 
@@ -2041,7 +2044,7 @@ Oliver Schieche E<lt>schiecheo@cpan.orgE<gt>
 
 http://perfect-co.de/
 
-$Id: OO.pm 50 2015-09-02 11:18:42Z schieche $
+$Id: OO.pm 53 2015-09-03 13:18:00Z schieche $
 
 =head1 LICENSE AND COPYRIGHT
 
